﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Security;

namespace BasicAuth.Controllers
{
    public class AuthorizationModel
    {
        public string Login { get; set; }
        public string Password { get; set; }
        public string ReturnUrl { get; set; }
    }

    public class PartialUserInfo
    {
        public string Name { get; set; }
    }

    public class AccountController : Controller
    {
        private readonly AuthorizationService _authorizationService = new AuthorizationService();

        public AccountController()
        {
        }

        //
        // GET: /Account/
        [Authorize]  // Этот атрибут позволяет просматривать страничку /Account только авторизованным пользователям
        // если при обращении к ней вы не авторизованы - вас редиректнет на /Account/LogOn
        public ActionResult Index()
        {
            return View();
        }

        [ChildActionOnly] // этот экшн сгенерит форму логина или покажет приветствие пользователя для уже авторизованных лиц
        // использовать как @Html.RenderAction<AccountController>(x=>x.LogOnPartial());
        public ActionResult LogOnPartial(AuthorizationModel model = null)
        {
            if (User.Identity.IsAuthenticated)
            {
                return PartialView("PartialUserInfo", new PartialUserInfo { Name = User.Identity.Name });
            }

            return PartialView(model ?? new AuthorizationModel());
        }

        public ActionResult LogOut()
        {
            FormsAuthentication.SignOut(); // разлогиниваем текущего пользователя
            return View();
        }

        [HttpPost]
        public ActionResult LogOn(AuthorizationModel model)
        {
            if (_authorizationService.ValidateUser(model.Login, model.Password)) // валидируем пользователя
            {
                FormsAuthentication.SetAuthCookie(model.Login, true); // выставляем куки для авторизованных лиц
                if (!String.IsNullOrEmpty(model.ReturnUrl))
                {
                    return Redirect(model.ReturnUrl);
                }

                return RedirectToAction("Index");
            }

            ModelState.AddModelError("", "The user name or password provided is incorrect.");

            return View(model);
        }

        public ActionResult LogOn()
        {
            return View(new AuthorizationModel { ReturnUrl = Request.Params["ReturnUrl"] }); //показываем форму авторизации
        }

    }
}
